@@ -34,13 +34,11 @@
 #include <glib.h>
 #include <glib/gstdio.h>
 #include <glib/gi18n-lib.h>
-#include <gio/gioerror.h>
-#include <gio/gseekable.h>
+#include <gio/gio.h>
+#include <gio/gunixinputstream.h>
+#include <gio/gunixoutputstream.h>
 #include "gdaemonfileoutputstream.h"
 #include "gvfsdaemondbus.h"
-#include <gio/gsocketinputstream.h>
-#include <gio/gsocketoutputstream.h>
-#include <gio/gsimpleasyncresult.h>
 #include <gvfsdaemonprotocol.h>
 
 #define MAX_WRITE_SIZE (4*1024*1024)
@@ -49,14 +47,14 @@ typedef enum {
   STATE_OP_DONE,
   STATE_OP_READ,
   STATE_OP_WRITE,
-  STATE_OP_SKIP,
+  STATE_OP_SKIP
 } StateOp;
 
 typedef enum {
   WRITE_STATE_INIT = 0,
   WRITE_STATE_WROTE_COMMAND,
   WRITE_STATE_SEND_DATA,
-  WRITE_STATE_HANDLE_INPUT,
+  WRITE_STATE_HANDLE_INPUT
 } WriteState;
 
 typedef struct {
@@ -79,7 +77,7 @@ typedef struct {
 typedef enum {
   SEEK_STATE_INIT = 0,
   SEEK_STATE_WROTE_REQUEST,
-  SEEK_STATE_HANDLE_INPUT,
+  SEEK_STATE_HANDLE_INPUT
 } SeekState;
 
 typedef struct {
@@ -101,7 +99,7 @@ typedef struct {
 typedef enum {
   CLOSE_STATE_INIT = 0,
   CLOSE_STATE_WROTE_REQUEST,
-  CLOSE_STATE_HANDLE_INPUT,
+  CLOSE_STATE_HANDLE_INPUT
 } CloseState;
 
 typedef struct {
@@ -224,8 +222,8 @@ g_daemon_file_output_stream_class_init (GDaemonFileOutputStreamClass *klass)
   
   gobject_class->finalize = g_daemon_file_output_stream_finalize;
 
-  stream_class->write = g_daemon_file_output_stream_write;
-  stream_class->close = g_daemon_file_output_stream_close;
+  stream_class->write_fn = g_daemon_file_output_stream_write;
+  stream_class->close_fn = g_daemon_file_output_stream_close;
   
   stream_class->write_async = g_daemon_file_output_stream_write_async;
   stream_class->write_finish = g_daemon_file_output_stream_write_finish;
@@ -255,8 +253,8 @@ g_daemon_file_output_stream_new (int fd,
 
   stream = g_object_new (G_TYPE_DAEMON_FILE_OUTPUT_STREAM, NULL);
 
-  stream->command_stream = g_socket_output_stream_new (fd, FALSE);
-  stream->data_stream = g_socket_input_stream_new (fd, TRUE);
+  stream->command_stream = g_unix_output_stream_new (fd, FALSE);
+  stream->data_stream = g_unix_input_stream_new (fd, TRUE);
   stream->can_seek = can_seek;
   stream->current_offset = initial_offset;
   
@@ -384,7 +382,10 @@ run_sync_state_machine (GDaemonFileOutputStream *file,
 				       &io_error);
 	}
       else
-	g_assert_not_reached ();
+	{
+	  res = 0;
+	  g_assert_not_reached ();
+	}
 
       if (res == -1)
 	{
@@ -951,7 +952,7 @@ g_daemon_file_output_stream_seek (GFileOutputStream *stream,
   
   if (!run_sync_state_machine (file, (state_machine_iterator)iterate_seek_state_machine,
 			       &op, cancellable, error))
-    return -1; /* IO Error */
+    return FALSE; /* IO Error */
 
   if (!op.ret_val)
     g_propagate_error (error, op.ret_error);
